@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 use Rope::Object;
 use Rope::Pro;
 my (%META, %PRO);
@@ -133,6 +133,23 @@ BEGIN {
 				$META{$caller}{requires}{$_}++ for (@requires);
 			};
 		},
+		private => sub {
+			my ($caller) = shift;
+			return sub {
+				shift @_ if $_[0] eq $caller;
+				my ($prop, @options) = @_;
+				$prop = shift @options if ( @options > 1 );
+				$PRO{set_prop}(
+					$caller,
+					$prop,
+					value => $options[0],
+					enumerable => 0,
+					writeable => 0,
+					initable => 0,
+					private => 1,
+				);
+			};
+		},
 		function => sub {
 			my ($caller) = shift;
 			return sub {
@@ -439,7 +456,7 @@ sub import {
 	$PRO{keyword}($caller, $_, $PRO{$_}($caller))
 		for $options->{import} 
 			? @{$options->{import}} 
-			: qw/function property properties prototyped extends with requires before around after locked destroy DESTROY new/;
+			: qw/function property properties prototyped private extends with requires before around after locked destroy DESTROY new/;
 }
 
 sub new {
@@ -626,7 +643,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.39
+Version 0.40
 
 =cut
 
@@ -806,6 +823,15 @@ NOTE: traditional sub routines work and should be inherited also.
 		...
 	}
 
+=head2 private
+
+Extends the current object definition with a new property that is private and only accessible to the current class. A private property has initable, writeable, enumerable and configurable all set to false so it cannot be changed/set once the object is instantiated.
+
+	private five => sub {
+		my ($self, $param) = @_;
+		...
+	};
+
 =head2 extends
 
 The extends keyword allows you to extend your current definition with another object, your object will inherit all the properties of that extended object.
